/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.location;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.app.domain.location.LocationTag;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;
import java.util.stream.Collectors;
import lombok.AccessLevel;
import lombok.Builder;
import lombok.Data;
import lombok.experimental.FieldDefaults;

/**
 * 定位标签导出模型
 * @author LJ-2204
 * @date 2022/4/14
 */

@ExcelModel
@Data
@Builder
@FieldDefaults(level = AccessLevel.PRIVATE)
public class LocationTagExportExcel implements Serializable {

    private static final long serialVersionUID = -4549580878785078998L;

    @ExcelColumn(title = "主键")
    @JsonSerialize(using = ToStringSerializer.class)
    Long id;

    @ExcelColumn(title = "编号")
    String code;

    @ExcelColumn(title = "标签类型")
    LocationTag.Type type;

    @ExcelColumn(title = "状态")
    Boolean silent;

    @ExcelColumn(title = "imei")
    String imei;

    @ExcelColumn(title = "电量")
    Integer volt;

    @ExcelColumn(title = "最近更新时间")
    LocalDateTime updateTime;

    public static List<LocationTagExportExcel> transforms(List<LocationTag> locationTags) {
        return locationTags
            .stream()
            .map(locationTag ->
                LocationTagExportExcel
                    .builder()
                    .id(locationTag.getId())
                    .code(locationTag.getCode())
                    .type(locationTag.getType())
                    .silent(locationTag.getSilent())
                    .imei(locationTag.getImei())
                    .volt(locationTag.getVolt())
                    .updateTime(locationTag.getUpdateTime())
                    .build()
            )
            .collect(Collectors.toList());
    }
}
